@@ -12,11 +12,6 @@ from sklearn.base import RegressorMixin, BaseEstimator
 
 logger = logging.getLogger(__name__)
 
-try:
-    from folium import Map
-except ImportError:
-    logger.warning('Folium not installed, not all visualization will work')
-
 
 class ExtendedEnum(Enum):
 
@@ -180,6 +175,7 @@ class MethodsT(ExtendedEnum):
     PHA = 'PHA'
     AHP = 'AHP'
     BU = 'BU'
+    NONE = 'NONE'
 
 
 # TODO: make this a proper recursive type when mypy supports it: https://github.com/python/mypy/issues/731
