@@ -8,7 +8,7 @@ def test_instantiate_revision(load_df_and_hier_uv):
     hierarchical_sine_data, sine_hier = load_df_and_hier_uv
     hsd = hierarchical_sine_data.head(200)
 
-    for method in ['OLS', 'FP', 'WLSS', 'WLSV', 'PHA', 'AHP']:
+    for method in ['OLS', 'FP', 'WLSS', 'WLSV', 'PHA', 'AHP', 'NONE']:
         ht = HTSRegressor(model='holt_winters', revision_method=method)
         ht.fit(df=hsd, nodes=sine_hier)
 
